import re
import datetime
from youtubed2x_lib.parsers import Parser_Helper, getPage, mimevault


class GiantBomb_Parser (Parser_Helper):
    """Parser for GiantBomb pages. Updated 01/15/2010"""
    const_video_url_re = re.compile (r'^(?:http://)?(?:www\.)?giantbomb\.com/(\S+)')
    video_url_str = 'http://www.giantbomb.com/%s'
    video_details_url = 'http://www.giantbomb.com/video/params/%s/'

    video_title_re = re.compile (r'<title><!\[CDATA\[([^\[]*)]]></title>')
    video_embed_code_re = re.compile (r'flashvars="paramsURI=http%3A//www.giantbomb.com/video/params/(\d+)/(?:\?w=1)?"')
    video_url_params_re = re.compile (r'<URI bitRate="700">(\S+)</URI>')

    parser_type = "GiantBomb"
    domain_str = "http://www.giantbomb.com/"
    host_str = "giantbomb.com"
    mime_base = mimevault.MimeVault ()
    mime_base.add_type ("application/octet-stream", ".flv")
    version = datetime.date (2010, 1, 15)


    def getVideoPage (self, account="", password=""):
        page, newurl = super (GiantBomb_Parser, self).getVideoPage (account, password)
        match = self.__class__.video_embed_code_re.search (page)
        if match:
            newurl = self.__class__.video_details_url % match.group (1)
            page, newurl = getPage (newurl)

        return page, newurl


    def _parseRealURL (self, commands):
        """Get the real url for the video"""
        real_url = commands[0]
        return real_url


    @staticmethod
    def getImageData ():
        image_data = """\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\xd4''\xff\xe5wq\xff\xe0=\x17\xff\xcc\x00\x00\xff\xf3\xc3\xc3\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\x00\x00\x00\x00\x00\x00\x00\x00\xee\xab\xab\xff\xd7 \x0b\xffW4\x11\xff\xe9X\x1d\xff\xedc!\xff\xd0\x12\x12\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xee\xab\xab\xff\xcf\t\x03\xff\xf5z)\xff\xff\x993\xff\xff\x993\xff\xf8\x861\xff\xfc\xd6\xbd\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\x00\x00\x00\x00\x00\x00\x00\x00\xe4xx\xff\xcc\x00\x00\xff\xcc\x00\x00\xff\xe6O\x1a\xff\xff\x993\xff\xff\x993\xff\xd4\x19\x08\xff\xd1\x1b\x1b\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\xd8<<\xff\xcc\x00\x00\xff\xcc\x00\x00\xff\xce\x07\x02\xff\xeaZ\x1e\xff\xd9&\r\xff\xf5z)\xff\xd1\x10\x05\xff\xcc\x00\x00\xff\x00\x00\x00\x00\x00\x00\x00\x00CCC\xff\x04\x04\x04\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x04\x04\x04\xffBAA\xff\xf5\xcc\xcc\xff\xf3\xc3\xc3\xff\xcd\x03\x03\xff\xcc\x00\x00\xff\xdfWR\xff\xf6\xc7\xbe\xff\xf8\xdb\xdb\xff\x00\x00\x00\x00\x1b\x1b\x1b\xff\x00\x00\x00\xff\x00\x00\x00\xff\xff\xff\xff\xff\xff\xff\xff\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x1b\x1b\x1b\xff\x00\x00\x00\x00\xdbKK\xff\xcc\x00\x00\xff\xf1\xba\xba\xff\x00\x00\x00\x00\x00\x00\x00\x00CCC\xff\x00\x00\x00\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xffCCC\xff\xed\xa5\xa5\xff\xd1\x18\x18\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x04\x04\x04\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x04\x04\x04\xfffff\xff\xe5{{\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\x00\x00\x00\xff\xff\xff\xff\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xfffff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xfffff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xfffff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x04\x04\x04\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x04\x04\x04\xfffff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00CCC\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xffCCC\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x1b\x1b\x1b\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x1b\x1b\x1b\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00CCC\xff\x04\x04\x04\xff\x00\x00\x00\xff\x00\x00\x00\xff\x00\x00\x00\xff\x04\x04\x04\xffCCC\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"""

        return image_data


