import re
from urllib2 import unquote
import datetime
from youtubed2x_lib.parsers import Parser_Helper, getPage


class YahooVideo_Parser (Parser_Helper):
    """Parser for Yahoo Video pages. Updated 07/04/2009"""
    const_video_url_re = re.compile (r'^(?:http://)?(?:www\.)?video\.yahoo\.com/(\S+)')
    video_url_str = 'http://video.yahoo.com/%s'
    video_details_page = "http://cosmos.bcst.yahoo.com/up/yep/process/getPlaylistFOP.php?node_id=%s"
    video_title_re = re.compile (r'<h1 id="vidTitle_(?:\d+)" class="ti-(?:\d+)">([^<]*)</h1>')
    video_details_re = re.compile (r'so.addVariable\("id", "(\w+)"\);')
    video_url_params_re = re.compile (r'<STREAM APP="(\S+)" FULLPATH="(\S+)" CLIPID')
    parser_type = "Yahoo Video"
    domain_str = "http://video.yahoo.com/"
    host_str = "video.yahoo.com"
    version = datetime.date (2009, 11, 28)


    def _parsePlayerCommands (self):
        """Get the commands needed to get the video player"""
        match = self.__class__.video_details_re.search (self.page_dump)
        if not match:
            raise self.__class__.InvalidCommands ("Could not find flash player commands")
        else:
            video_id = match.group (1)

        page, newurl = getPage (self.__class__.video_details_page % video_id)
        match = self.__class__.video_url_params_re.search (page)
        if not match:
            raise self.__class__.InvalidCommands ("Could not find flash player commands")
        else:
            commands = match.groups ()

        return commands


    def _parseRealURL (self, commands):
        """Get the real url for the video"""
        if commands[0].startswith ("rtmp://"):
#            print "%s/%s" % (commands[0], commands[1])
            raise self.__class__.InvalidCommands ("RTMP service not supported")

        path = commands[1]
        if path.startswith ("//"):
            path = path.lstrip ("//") # Remove beginning / characters

        secondary_url = "%s/%s" % (commands[0], path)
        secondary_url = secondary_url.replace ("&amp;", "&")
        real_url = unquote (secondary_url)
        return real_url


    @staticmethod
    def getImageData ():
        image_data = """\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\x00\x007\xff\x00\x00^\xff\x00\x00]\xff\x00\x00]\xff\x00\x00]\xfd\x00\x00`\xff\x00\x00\x1a\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xf3\x00\x00\x85\xdd\x00\x00\xf3\xff\x00\x00\xff\xff\x00\x00\xff\xea\x03\x03\xff\xe6\x00\x00\xf0d\x00\x00\xc3\xff\x00\x00\x0e\xff\t\t5\xff\x08\x083\xff\x08\x083\xff\t\t4\xcb\x00\x00+\xff\x00\x00\x93\xff\x02\x02\xa6\x9e\x00\x005\x00\x00\x00\x02\x00\x00\x00\x16\xff\x00\x00I\xff\x00\x00\xff\xde\x03\x03\xff\x19\x00\x00c\x00\x00\x00\t\xff\x00\x005\x9e\x01\x01\xff\xfb\x07\x07\xff\xc6\x04\x04\xff\x9d\x01\x01\xff[\x00\x00\xe6\xff\x00\x00\xe2\xf6\x03\x03\xff?\x02\x02\xa3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\x00\x00k\xff\x00\x00\xff\xdb\x00\x00\xff2\x00\x00K\xe2\x00\x00\x15\xff\x04\x04\x7f\xb4\x03\x03\xff\x00\x00\x00k\x00\x00\x00\x00\xff\x00\x001\xfe\x01\x01\xff\xe0\x00\x00\xffa\x00\x00*\x00\x00\x00\x00\x00\x00\x00\x00\xff\x00\x00\x00\x00\x00\x00\x00\xfe\x00\x00K\xff\x00\x00\xff\xef\x00\x00\xfa\xff\x03\x03\xee\xb3\x04\x04\xff\x00\x00\x00K\x00\x00\x00\x00\x00\x00\x00\x00\xff\x00\x00\x94\xff\x07\x07\xff\x89\x00\x00\xe4\x00\x00\x00\x0e\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\x00\x00\x81\xff\x00\x00\xff\xc5\x00\x00\xff\x00\x00\x00k\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\x00\x00\xed\xf5\x00\x00\xff\x00\x00\x00y\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\x00\x00[\xff\x00\x00\xff\x96\x00\x00\xff\x00\x00\x00\x00\x00\x00\x00\x00\xff\x00\x00\x00\x00\x00\x00\x00_\x00\x00n*\x00\x00\xac\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xfc\x00\x00\x14\xff\x00\x003\xff\x00\x00}\xff\x00\x00\xff\xae\x00\x00\xff\xff\x00\x00&\x8a\x00\x00\x14\x00\x00\x00\x00\xff\x00\x00\xdb\xf5\x00\x00\xff\xbe\x00\x00!\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\x00\x005\x98\x00\x00\xff\x99\x00\x00\xff\x97\x00\x00\xff\x9a\x00\x00\xff\x9b\x00\x00\xff4\x00\x00\xa5\x00\x00\x00\x00\xc2\x00\x00\xa9\x85\x00\x00\xffB\x00\x007\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x008\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"""

        return image_data


