import os, sys
import datetime
from xml.etree import ElementTree as ET
import urllib2
from youtubed2x_lib.other import UserDirectoryIndex

class EntryNotFound (Exception): pass
class InvalidXMLFile (Exception): pass


class ParserRepo (object):
    XML_DATA_URL = "http://www.ryochan7.com/files/repo.xml"

    def __init__ (self):
        self.req = urllib2.Request (self.__class__.XML_DATA_URL)
        #self.xml_data = ""
        self.parser_list = []


    def parse (self):
        handle = urllib2.urlopen (self.req)
        xml_data = ET.parse (handle)
        handle.close ()
        self.parser_list = []

        root_tag = self.xml_data.getroot ()
        if root_tag.tag != "parser_list":
            raise InvalidXMLFile ("No parser_list root node present in repo xml file")

        for parser in root_tag.getchildren ():
            if parser.tag != "parser":
                raise InvalidXMLFile ("Child node in repo xml file must be a parser")

            name = getattr (parser.find ("name"), "text", None)
            version_text = getattr (parser.find ("version"), "text", None)
            host = getattr (parser.find ("host"), "text", None)
            download_url = getattr (parser.find ("download_url"), "text", None)

            if not name or not version or not download_url or not host:
                sys.stderr.write ("XML is missing a required attribute. Skipping indexing the following:")
                sys.stderr.write ("%s" % ET.tostring (element))
                return


        for element in self.xml_data.findall ("parser"):
            name = ""
            version = None
            host = ""
            download_url = ""
            for subelement in element:
                if subelement.tag == "name":
                    name = subelement.text
                elif subelement.tag == "version":
                    jversion = subelement.text
                    jversion = jversion.split (".")
                    if len (jversion) == 3:
                        year = int (jversion[0])
                        month = int (jversion[1])
                        day = int (jversion[2])
                        version = datetime.date (year, month, day)
                    else:
                        raise InvalidXMLFile ("Version not properly formatted in following XML: \n%s" % ET.tostring (element))

                elif subelement.tag == "download_url":
                    download_url = subelement.text
                elif subelement.tag == "host":
                    host = subelement.text
                else:
                    raise InvalidXMLFile ("Tag %s is unknown" % subelement.tag)

            if not name or not version or not download_url or not host:
                print >> sys.stderr, "XML is missing a required attribute. Skipping indexing the following:"
                print >> sys.stderr, "%s" % ET.tostring (element)
                return

            parser_found = False
            for item in self.parser_list:
                if host is item["host"]:
                    parser_found = True
                    break

            if not parser_found:
                self.parser_list.append ({"name": name, "version": version, "download_url": download_url, "host": host})

        return list (self.parser_list)


    def getParserEntry (self, parser_host):
        for element in self.parser_list:
            if parser_host == element["host"]:
                return element


    def downloadParser (self, parser_host):
        download_url = ""
        for element in self.parser_list:
            if parser_host == element["host"]:
                download_url = element["download_url"]
                break

        if not download_url:
            raise EntryNotFound ("")

        req = urllib2.Request (download_url)
        handle = urllib2.urlopen (req)
        module_data = handle.read ()
        handle.close ()

        
        user_parser_dir = os.path.join (UserDirectoryIndex.config_dir, "parsers")

        if not os.path.exists (UserDirectoryIndex.config_dir):
            try:
                os.mkdir (UserDirectoryIndex.config_dir)
            except OSError:
                print >> sys.stderr, "Could not create config directory \"%s\"" % UserDirectoryIndex.config_dir

        if not os.path.exists (user_parser_dir):
            try:
                os.mkdir (user_parser_dir)
            except OSError:
                print >> sys.stderr, "Could not create user parser directory \"%s\"." % user_parser_dir


        file = open (os.path.join (user_parser_dir, "%s.py" % element["name"].lower ()), 'w')
        file.write (module_data)
        file.close ()


