import os, sys
import datetime
from xml.etree import ElementTree as ET
import urllib2
from youtubed2x_lib.other import UserDirectoryIndex

class EntryNotFound (Exception): pass
class InvalidXMLFile (Exception): pass


class ParserRepo (object):
    XML_DATA_URL = "http://www.ryochan7.com/files/repo.xml"

    def __init__ (self):
        self.req = urllib2.Request (self.__class__.XML_DATA_URL)
        self.parser_list = []


    def parse (self):
        handle = urllib2.urlopen (self.req)
        xml_data = ET.parse (handle)
        handle.close ()
        self.parser_list = []

        root_tag = xml_data.getroot ()
        if root_tag.tag != "parser_list":
            raise InvalidXMLFile ("No parser_list root node present in repo xml file")

        for parser in root_tag.getchildren ():
            if parser.tag != "parser":
                raise InvalidXMLFile ("Child node in repo xml file must be a parser")

            name = getattr (parser.find ("name"), "text", None)
            version_text = getattr (parser.find ("version"), "text", "")
            version_text = version_text.split (".")
            host = getattr (parser.find ("host"), "text", None)
            download_url = getattr (parser.find ("download_url"), "text", None)
            if len (version_text) == 3:
                year = int (version_text[0])
                month = int (version_text[1])
                day = int (version_text[2])
                version = datetime.date (year, month, day)
            else:
                raise InvalidXMLFile ("Version not properly formatted in following XML: \n%s" % ET.tostring (element))

            if not name or not version or not download_url or not host:
                sys.stderr.write ("XML is missing a required attribute. Skipping indexing the following:\n")
                sys.stderr.write ("%s" % ET.tostring (element))
                return

            parser_found = False
            for item in self.parser_list:
                if host is item["host"]:
                    parser_found = True
                    break

            if not parser_found:
                self.parser_list.append ({"name": name, "version": version, "download_url": download_url, "host": host})

        return list (self.parser_list)


    def getParserEntry (self, parser_host):
        for element in self.parser_list:
            if parser_host == element["host"]:
                return element

        return None


    def downloadParser (self, parser_host):
        element = self.getParserEntry (parser_host)
        if not element:
            raise EntryNotFound ("Specified parser host was not found in parser list")

        download_url = element["download_url"]
        req = urllib2.Request (download_url)
        handle = urllib2.urlopen (req)
        module_data = handle.read ()
        handle.close ()

        user_parser_dir = os.path.join (UserDirectoryIndex.config_dir, "parsers")
        if not os.path.exists (UserDirectoryIndex.config_dir):
            try:
                os.mkdir (UserDirectoryIndex.config_dir)
            except (OSError, IOError) as error:
                print >> sys.stderr, "Could not create config directory \"%s\"" % UserDirectoryIndex.config_dir
                return False

        if not os.path.exists (user_parser_dir):
            try:
                os.mkdir (user_parser_dir)
            except (OSError, IOError) as error:
                print >> sys.stderr, "Could not create user parser directory \"%s\"." % user_parser_dir
                return False

        filename = os.path.basename (download_url)
        location = os.path.join (user_parser_dir, filename)
        print location
        try:
            file = open (location, 'w')
            file.write (module_data)
            file.close ()
        except (OSError, IOError) as error:
            sys.stderr.write ("Could not write file \"%s\"" % location)
            return False

        return True

